@@ -86,6 +86,7 @@ def parse(html: str, p: Product, include: Sequence = None):
     "thumbnail" in include and parse_thumbnail(p, selector=sel)
     "category" in include and parse_category(p, selector=sel)
     "currency" in include and parse_currency(p, selector=sel)
+    "date_first_avail" in include and parse_date_first_avail(p, selector=sel)
 
 
 def parse_parent_asin(p: Product, selector: parsel.Selector = None):
@@ -461,3 +462,15 @@ def parse_category(p: Product, selector: parsel.Selector = None):
 
 def parse_currency(p: Product, selector: parsel.Selector = None):
     p.currency = None
+
+
+def parse_date_first_avail(p: Product, selector: parsel.Selector = None):
+    date = product_details_detail_bullets(selector, "Date First Available")
+    date = date or selector.xpath(
+        "//div[@id='detailBullets_feature_div']//span[contains(text(), 'Date First Available')]/"
+        "following-sibling::span[1]/text()"
+    ).get()
+    if date == "":
+        p.date_first_avail = None
+    else:
+        p.date_first_avail = date
