@@ -8,7 +8,7 @@ from extreme_parser.util.parse import parse_number
 
 
 def parse_context(selector: parsel.Selector = None) -> Union[dict, None]:
-    c = selector.re_first(r'Etsy.Context=({.*})')
+    c = selector.re_first(r'Etsy.Context=({.*})', replace_entities=False)
     if c is None:
         return None
     else:
